@@ -94,7 +94,12 @@ class Node:
     @staticmethod
     def _bash_template(command: str) -> str:
         return f"""#!/bin/bash
+echo Working Directory
+pwd
+echo Host Python Environment
+pip list
 echo Creating Virtual Environment
+rm -rf .task_venv
 virtualenv .task_venv --system-site-packages
 echo Activate Environment
 source .task_venv/bin/activate
